#ifndef OBGTK_ACCEL_LABEL_H
#define OBGTK_ACCEL_LABEL_H 1

#include <obgtk/obgtkLabel.h>
#include <gtk/gtkaccellabel.h>

@interface Gtk_AccelLabel : Gtk_Label
{
@public
  GtkAccelLabel *gtkaccellabel;
}

- castGtkAccelLabel:(GtkAccelLabel *) castitem;
- (guint) get_accelerator_width;
- set_accel_widget:(id) accel_widget;
- (gboolean) refetch;
@end

#endif /* OBGTK_LABEL_H */
